==> gnome-chemistry-utils-0.7.4.tar.gz: gnome-chemistry-utils-0.7.4/programs/crystal/window.h <==
// -*- C++ -*-

/* 
 * Gnome Crystal
 * window.h 
 *
 * Copyright (C) 2006 Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCRYSTAL_WINDOW_H
#define GCRYSTAL_WINDOW_H

#include <gcu/macros.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkwindow.h>
#include <gtk/gtkuimanager.h>

class gcApplication;
class gcDocument;
class gcView;

class gcWindow
{
public:
	gcWindow (gcApplication *App, gcDocument *Doc);
	~gcWindow ();

	gcApplication *GetApplication () {return m_App;}
	void ClearStatus ();
	void SetStatusText (const char* text);
	bool TryClose ();
	void Destroy ();

private:
	GtkUIManager* m_UIManager;
	GtkWindow* m_Window;
	GtkWidget* m_Bar;	//GtkStatusBar
	unsigned m_statusId;
	unsigned m_MessageId; //currently displayed message in the status bar

GCU_RO_PROP (gcApplication *, App);
GCU_RO_PROP (gcView *, View);
GCU_RO_PROP (gcDocument *, Doc);
};

#endif	//	GCRYSTAL_WINDOW_H

==> gnome-chemistry-utils_0.8.7.orig.tar.gz: gnome-chemistry-utils-0.8.7/programs/crystal/window.h <==
// -*- C++ -*-

/* 
 * Gnome Crystal
 * window.h 
 *
 * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCRYSTAL_WINDOW_H
#define GCRYSTAL_WINDOW_H

#include <gcu/macros.h>
#include <gtk/gtkwidget.h>
#include <gtk/gtkwindow.h>
#include <gtk/gtkuimanager.h>

class gcApplication;
class gcDocument;
class gcView;

class gcWindow
{
public:
	gcWindow (gcApplication *App, gcDocument *Doc);
	~gcWindow ();

	gcApplication *GetApplication () {return m_App;}
	void ClearStatus ();
	void SetStatusText (const char* text);
	bool TryClose ();
	void Destroy ();
	void ActivateActionWidget (char const *path, bool activate); 

private:
	GtkUIManager* m_UIManager;
	GtkWidget* m_Bar;	//GtkStatusBar
	unsigned m_statusId;
	unsigned m_MessageId; //currently displayed message in the status bar

GCU_RO_PROP (gcApplication *, App);
GCU_RO_PROP (gcView *, View);
GCU_RO_PROP (gcDocument *, Doc);
GCU_RO_PROP (GtkWindow *, Window);
};

#endif	//	GCRYSTAL_WINDOW_H
